@@ -6,13 +6,20 @@ package Mite::Attribute;
 use Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001013';
+our $VERSION   = '0.002000';
 
 has class =>
   is            => rw,
   isa           => Object,
   weak_ref      => true;
 
+has _class_for_default =>
+  is            => rw,
+  isa           => Object,
+  weak_ref      => true,
+  lazy          => true,
+  builder       => sub { shift->class };
+
 has name =>
   is            => rw,
   isa           => Str->where('length($_) > 0'),
@@ -77,7 +84,7 @@ has coderef_default_variable =>
   lazy          => true,     # else $self->name might not be set
   default       => sub {
       # This must be coordinated with Mite.pm
-      return sprintf '$__%s_DEFAULT__', $_[0]->name;
+      return sprintf '$%s::__%s_DEFAULT__', $_[0]->_class_for_default->name, $_[0]->name;
   };
 
 has [ 'trigger', 'builder' ] =>
@@ -159,14 +166,13 @@ sub BUILD {
 sub clone {
     my ( $self, %args ) = ( shift, @_ );
 
-    $args{name} //= $self->name;
-    $args{is}   //= $self->is;
+    my %inherit = %$self;
 
-    # Because undef is a valid default
-    $args{default} = $self->default
-        if !exists $args{default} and $self->has_default;
+    # Lazy attributes should be rebuilt by clone
+    delete $inherit{type} if $args{isa} || $args{type};
+    delete $inherit{coderef_default_variable};
 
-    return ref($self)->new( %args );
+    return ref($self)->new( %inherit, %args );
 }
 
 sub is_private {
@@ -318,8 +324,8 @@ sub _compile_default {
 
     if ( $self->has_coderef_default ) {
         my $var = $self->coderef_default_variable;
-        return sprintf 'do { our %s; %s->(%s) }',
-          $var, $var, $selfvar;
+        return sprintf 'do { my $method = %s; %s->$method }',
+          $var, $selfvar;
     }
     elsif ( $self->has_simple_default ) {
         require B;
