@@ -5,7 +5,7 @@ use warnings;
 package Mite::Miteception;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001013';
+our $VERSION   = '0.002000';
 
 my %constants;
 BEGIN {
@@ -96,7 +96,7 @@ sub load_mite_file {
 		 require $mite_file;
 	}
 
-	'Mite::Shim'->_install_exports( $caller, $file );
+	'Mite::Shim'->_inject_mite_class_functions( $caller, $file );
 }
 
 1;
