@@ -1,6 +1,6 @@
 {
 package Mite::Project;
-our $USES_MITE = 1;
+our $USES_MITE = q[Mite::Class];
 use strict;
 use warnings;
 
@@ -14,7 +14,7 @@ sub new {
 
     # Initialize attributes
     if ( exists($args->{q[config]}) ) { (do { use Scalar::Util (); Scalar::Util::blessed($args->{q[config]}) and $args->{q[config]}->isa(q[Mite::Config]) }) or require Carp && Carp::croak(q[Type check failed in constructor: config should be InstanceOf["Mite::Config"]]); $self->{q[config]} = $args->{q[config]};  }
-    if ( exists($args->{q[sources]}) ) { (do { package Mite::Miteception; ref($args->{q[sources]}) eq 'HASH' } and do { my $ok = 1; for my $i (values %{$args->{q[sources]}}) { ($ok = 0, last) unless (do { use Scalar::Util (); Scalar::Util::blessed($i) and $i->isa(q[Mite::Source]) }) }; $ok }) or require Carp && Carp::croak(q[Type check failed in constructor: sources should be HashRef[InstanceOf["Mite::Source"]]]); $self->{q[sources]} = $args->{q[sources]};  } else { my $value = do { my $default_value = do { our $__sources_DEFAULT__; $__sources_DEFAULT__->($self) }; do { package Mite::Miteception; (ref($default_value) eq 'HASH') and do { my $ok = 1; for my $i (values %{$default_value}) { ($ok = 0, last) unless (do { use Scalar::Util (); Scalar::Util::blessed($i) and $i->isa(q[Mite::Source]) }) }; $ok } } or do { require Carp; Carp::croak(q[Type check failed in default: sources should be HashRef[InstanceOf["Mite::Source"]]]) }; $default_value }; $self->{q[sources]} = $value;  }
+    if ( exists($args->{q[sources]}) ) { (do { package Mite::Miteception; ref($args->{q[sources]}) eq 'HASH' } and do { my $ok = 1; for my $i (values %{$args->{q[sources]}}) { ($ok = 0, last) unless (do { use Scalar::Util (); Scalar::Util::blessed($i) and $i->isa(q[Mite::Source]) }) }; $ok }) or require Carp && Carp::croak(q[Type check failed in constructor: sources should be HashRef[InstanceOf["Mite::Source"]]]); $self->{q[sources]} = $args->{q[sources]};  } else { my $value = do { my $default_value = do { my $method = $Mite::Project::__sources_DEFAULT__; $self->$method }; do { package Mite::Miteception; (ref($default_value) eq 'HASH') and do { my $ok = 1; for my $i (values %{$default_value}) { ($ok = 0, last) unless (do { use Scalar::Util (); Scalar::Util::blessed($i) and $i->isa(q[Mite::Source]) }) }; $ok } } or do { require Carp; Carp::croak(q[Type check failed in default: sources should be HashRef[InstanceOf["Mite::Source"]]]) }; $default_value }; $self->{q[sources]} = $value;  }
 
     # Enforce strict constructor
     my @unknown = grep not( do { package Mite::Miteception; (defined and !ref and m{\A(?:(?:config|sources))\z}) } ), keys %{$args}; @unknown and require Carp and Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort @unknown));
@@ -66,10 +66,22 @@ sub __META__ {
     };
 }
 
+sub DOES {
+    my ( $self, $role ) = @_;
+    our %DOES;
+    return $DOES{$role} if exists $DOES{$role};
+    return 1 if $role eq __PACKAGE__;
+    return $self->SUPER::DOES( $role );
+}
+
+sub does {
+    shift->DOES( @_ );
+}
+
 my $__XS = !$ENV{MITE_PURE_PERL} && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
 # Accessors for config
-*config = sub { @_ > 1 ? require Carp && Carp::croak("config is a read-only attribute of @{[ref $_[0]]}") : ( exists($_[0]{q[config]}) ? $_[0]{q[config]} : ( $_[0]{q[config]} = do { my $default_value = do { our $__config_DEFAULT__; $__config_DEFAULT__->($_[0]) }; (do { use Scalar::Util (); Scalar::Util::blessed($default_value) and $default_value->isa(q[Mite::Config]) }) or do { require Carp; Carp::croak(q[Type check failed in default: config should be InstanceOf["Mite::Config"]]) }; $default_value } ) ) };
+*config = sub { @_ > 1 ? require Carp && Carp::croak("config is a read-only attribute of @{[ref $_[0]]}") : ( exists($_[0]{q[config]}) ? $_[0]{q[config]} : ( $_[0]{q[config]} = do { my $default_value = do { my $method = $Mite::Project::__config_DEFAULT__; $_[0]->$method }; (do { use Scalar::Util (); Scalar::Util::blessed($default_value) and $default_value->isa(q[Mite::Config]) }) or do { require Carp; Carp::croak(q[Type check failed in default: config should be InstanceOf["Mite::Config"]]) }; $default_value } ) ) };
 
 # Accessors for sources
 if ( $__XS ) {
