@@ -1,6 +1,6 @@
 {
 package Mite::Source;
-our $USES_MITE = 1;
+our $USES_MITE = q[Mite::Class];
 use strict;
 use warnings;
 
@@ -13,7 +13,7 @@ sub new {
     my $no_build = delete $args->{__no_BUILD__};
 
     # Initialize attributes
-    if ( exists($args->{q[classes]}) ) { (do { package Mite::Miteception; ref($args->{q[classes]}) eq 'HASH' } and do { my $ok = 1; for my $i (values %{$args->{q[classes]}}) { ($ok = 0, last) unless (do { use Scalar::Util (); Scalar::Util::blessed($i) and $i->isa(q[Mite::Class]) }) }; $ok }) or require Carp && Carp::croak(q[Type check failed in constructor: classes should be HashRef[InstanceOf["Mite::Class"]]]); $self->{q[classes]} = $args->{q[classes]};  } else { my $value = do { my $default_value = do { our $__classes_DEFAULT__; $__classes_DEFAULT__->($self) }; do { package Mite::Miteception; (ref($default_value) eq 'HASH') and do { my $ok = 1; for my $i (values %{$default_value}) { ($ok = 0, last) unless (do { use Scalar::Util (); Scalar::Util::blessed($i) and $i->isa(q[Mite::Class]) }) }; $ok } } or do { require Carp; Carp::croak(q[Type check failed in default: classes should be HashRef[InstanceOf["Mite::Class"]]]) }; $default_value }; $self->{q[classes]} = $value;  }
+    if ( exists($args->{q[classes]}) ) { (do { package Mite::Miteception; ref($args->{q[classes]}) eq 'HASH' } and do { my $ok = 1; for my $i (values %{$args->{q[classes]}}) { ($ok = 0, last) unless (do { use Scalar::Util (); Scalar::Util::blessed($i) and $i->isa(q[Mite::Class]) }) }; $ok }) or require Carp && Carp::croak(q[Type check failed in constructor: classes should be HashRef[InstanceOf["Mite::Class"]]]); $self->{q[classes]} = $args->{q[classes]};  } else { my $value = do { my $default_value = do { my $method = $Mite::Source::__classes_DEFAULT__; $self->$method }; do { package Mite::Miteception; (ref($default_value) eq 'HASH') and do { my $ok = 1; for my $i (values %{$default_value}) { ($ok = 0, last) unless (do { use Scalar::Util (); Scalar::Util::blessed($i) and $i->isa(q[Mite::Class]) }) }; $ok } } or do { require Carp; Carp::croak(q[Type check failed in default: classes should be HashRef[InstanceOf["Mite::Class"]]]) }; $default_value }; $self->{q[classes]} = $value;  }
     if ( exists($args->{q[compiled]}) ) { (do { use Scalar::Util (); Scalar::Util::blessed($args->{q[compiled]}) and $args->{q[compiled]}->isa(q[Mite::Compiled]) }) or require Carp && Carp::croak(q[Type check failed in constructor: compiled should be InstanceOf["Mite::Compiled"]]); $self->{q[compiled]} = $args->{q[compiled]};  }
     if ( exists($args->{q[file]}) ) { my $value = do { my $to_coerce = $args->{q[file]}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or require Carp && Carp::croak(q[Type check failed in constructor: file should be Path]); $self->{q[file]} = $value;  } else { require Carp; Carp::croak("Missing key in constructor: file") }
     if ( exists($args->{q[project]}) ) { (do { use Scalar::Util (); Scalar::Util::blessed($args->{q[project]}) and $args->{q[project]}->isa(q[Mite::Project]) }) or require Carp && Carp::croak(q[Type check failed in constructor: project should be InstanceOf["Mite::Project"]]); $self->{q[project]} = $args->{q[project]};  } require Scalar::Util && Scalar::Util::weaken($self->{q[project]});
@@ -68,6 +68,18 @@ sub __META__ {
     };
 }
 
+sub DOES {
+    my ( $self, $role ) = @_;
+    our %DOES;
+    return $DOES{$role} if exists $DOES{$role};
+    return 1 if $role eq __PACKAGE__;
+    return $self->SUPER::DOES( $role );
+}
+
+sub does {
+    shift->DOES( @_ );
+}
+
 my $__XS = !$ENV{MITE_PURE_PERL} && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
 # Accessors for classes
@@ -82,7 +94,7 @@ else {
 }
 
 # Accessors for compiled
-*compiled = sub { @_ > 1 ? require Carp && Carp::croak("compiled is a read-only attribute of @{[ref $_[0]]}") : ( exists($_[0]{q[compiled]}) ? $_[0]{q[compiled]} : ( $_[0]{q[compiled]} = do { my $default_value = do { our $__compiled_DEFAULT__; $__compiled_DEFAULT__->($_[0]) }; (do { use Scalar::Util (); Scalar::Util::blessed($default_value) and $default_value->isa(q[Mite::Compiled]) }) or do { require Carp; Carp::croak(q[Type check failed in default: compiled should be InstanceOf["Mite::Compiled"]]) }; $default_value } ) ) };
+*compiled = sub { @_ > 1 ? require Carp && Carp::croak("compiled is a read-only attribute of @{[ref $_[0]]}") : ( exists($_[0]{q[compiled]}) ? $_[0]{q[compiled]} : ( $_[0]{q[compiled]} = do { my $default_value = do { my $method = $Mite::Source::__compiled_DEFAULT__; $_[0]->$method }; (do { use Scalar::Util (); Scalar::Util::blessed($default_value) and $default_value->isa(q[Mite::Compiled]) }) or do { require Carp; Carp::croak(q[Type check failed in default: compiled should be InstanceOf["Mite::Compiled"]]) }; $default_value } ) ) };
 
 # Accessors for file
 if ( $__XS ) {
